@@ -44,7 +44,8 @@ def _global_example_event():
 
     print("******************** LOAD TEST EVENT ***********************")
 
-    with SimTelEventSource(input_url=filename) as reader:
+    # FIXME: switch to prod5b+ file that contains effective focal length
+    with SimTelEventSource(input_url=filename, focal_length_choice='nominal') as reader:
         event = next(iter(reader))
 
     return event
@@ -59,7 +60,7 @@ def example_subarray():
 
     print("******************** LOAD TEST EVENT ***********************")
 
-    with SimTelEventSource(input_url=filename) as reader:
+    with SimTelEventSource(input_url=filename, focal_length_choice='nominal') as reader:
         return reader.subarray
 
 
@@ -84,7 +85,7 @@ def _subarray_and_event_gamma_off_axis_500_gev():
 
     path = get_dataset_path("lst_prod3_calibration_and_mcphotons.simtel.zst")
 
-    with SimTelEventSource(path) as source:
+    with SimTelEventSource(path, focal_length_choice='nominal') as source:
         it = iter(source)
         # we want the second event, first event is a corner clipper
         next(it)
@@ -353,6 +354,7 @@ def dl1_muon_file(dl1_tmp_path):
             "--write-images",
             "--DataWriter.write_parameters=False",
             "--DataWriter.Contact.name=αℓℓ the äüöß",
+            "--SimTelEventSource.focal_length_choice=nominal",
         ]
         assert run_tool(ProcessorTool(), argv=argv, cwd=dl1_tmp_path) == 0
         return output
