@@ -2,7 +2,7 @@ import numpy as np
 import astropy.units as u
 from numpy.testing import assert_allclose
 from ctapipe.instrument.camera import CameraGeometry
-from ctapipe.containers import HillasParametersContainer
+from ctapipe.containers import CameraHillasParametersContainer
 
 
 def test_psi_0():
@@ -17,7 +17,7 @@ def test_psi_0():
     deviation = 0.1
 
     geom = CameraGeometry.from_name("LSTCam")
-    hillas = HillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=0 * u.deg)
+    hillas = CameraHillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=0 * u.deg)
 
     random = np.random.default_rng(0)
     peak_time = intercept + grad * geom.pix_x.value
@@ -47,7 +47,7 @@ def test_psi_20():
 
     geom = CameraGeometry.from_name("LSTCam")
     psi = 20 * u.deg
-    hillas = HillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=psi)
+    hillas = CameraHillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=psi)
 
     random = np.random.default_rng(0)
     peak_time = intercept + grad * (
@@ -77,7 +77,7 @@ def test_ignore_negative():
     deviation = 0.1
 
     geom = CameraGeometry.from_name("LSTCam")
-    hillas = HillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=0 * u.deg)
+    hillas = CameraHillasParametersContainer(x=0 * u.m, y=0 * u.m, psi=0 * u.deg)
 
     random = np.random.default_rng(0)
     peak_time = intercept + grad * geom.pix_x.value
