@@ -1,10 +1,11 @@
 from .description import CameraDescription
-from .geometry import CameraGeometry, UnknownPixelShapeWarning
+from .geometry import CameraGeometry, UnknownPixelShapeWarning, PixelShape
 from .readout import CameraReadout
 
 __all__ = [
     "CameraDescription",
     "CameraGeometry",
+    "PixelShape",
     "UnknownPixelShapeWarning",
     "CameraReadout",
 ]
