@@ -29,17 +29,13 @@ def test_hash():
     assert len(set(telescopes)) == 3
 
 
-OPTICS_NAMES = OpticsDescription.get_known_optics_names()
-CAMERA_NAMES = CameraDescription.get_known_camera_names()
-
-
-@pytest.mark.parametrize("camera_name", CAMERA_NAMES)
-@pytest.mark.parametrize("optics_name", OPTICS_NAMES)
-def test_telescope_from_name(optics_name, camera_name):
+@pytest.mark.parametrize("optics_name", ["LST", "MST"])
+def test_telescope_from_name(optics_name, camera_geometry):
     """ Check we can construct all telescopes from their names """
+    camera_name = camera_geometry.camera_name
     tel = TelescopeDescription.from_name(optics_name, camera_name)
     assert optics_name in str(tel)
     assert camera_name in str(tel)
     assert tel.camera.geometry.pix_x.shape[0] > 0
     assert tel.optics.equivalent_focal_length.to("m") > 0
-    assert tel.type in ["MST", "SST", "LST", "UNKNOWN"]
+    assert tel.type in {"MST", "SST", "LST", "UNKNOWN"}
