@@ -6,6 +6,8 @@ from traitlets import TraitError
 
 from ctapipe.core import Component
 
+prod5_path = "gamma_20deg_0deg_run2___cta-prod5-paranal_desert-2147m-Paranal-dark_cone10-100evts.simtel.zst"
+
 
 def test_construct():
     # at least one of input_url / parent / config is required
@@ -43,20 +45,20 @@ class DummyReader(EventSource):
 
 
 def test_can_be_implemented():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     test_reader = DummyReader(input_url=dataset)
     assert test_reader is not None
 
 
 def test_is_iterable():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     test_reader = DummyReader(input_url=dataset)
     for _ in test_reader:
         pass
 
 
 def test_function():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     reader = EventSource(input_url=dataset)
     assert isinstance(reader, SimTelEventSource)
     assert reader.input_url == dataset
@@ -75,7 +77,7 @@ def test_function_nonexistant_file():
 
 
 def test_from_config():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     config = Config({"EventSource": {"input_url": dataset}})
     reader = EventSource(config=config)
     assert isinstance(reader, SimTelEventSource)
@@ -83,7 +85,7 @@ def test_from_config():
 
 
 def test_from_config_parent():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
 
     class Parent(Component):
         def __init__(self, config=None, parent=None):
@@ -109,7 +111,7 @@ def test_from_config_parent():
 
 def test_from_config_default():
     old_default = EventSource.input_url.default_value
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     EventSource.input_url.default_value = dataset
     config = Config()
     reader = EventSource(config=config, parent=None)
@@ -119,7 +121,7 @@ def test_from_config_default():
 
 
 def test_from_config_invalid_type():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     EventSource.input_url.default_value = dataset
     config = Config({"EventSource": {"input_url": 124}})
     with pytest.raises(TraitError):
@@ -127,10 +129,10 @@ def test_from_config_invalid_type():
 
 
 def test_event_source_input_url_config_override():
-    dataset1 = get_dataset_path("gamma_test_large.simtel.gz")
-    dataset2 = get_dataset_path(
+    dataset1 = get_dataset_path(
         "gamma_LaPalma_baseline_20Zd_180Az_prod3b_test.simtel.gz"
     )
+    dataset2 = get_dataset_path(prod5_path)
 
     config = Config({"EventSource": {"input_url": dataset1}})
     reader = EventSource(input_url=dataset2, config=config)
@@ -141,13 +143,13 @@ def test_event_source_input_url_config_override():
 
 def test_max_events():
     max_events = 10
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     reader = EventSource(input_url=dataset, max_events=max_events)
     assert reader.max_events == max_events
 
 
 def test_max_events_from_config():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     max_events = 10
     config = Config({"EventSource": {"input_url": dataset, "max_events": max_events}})
     reader = EventSource(config=config)
@@ -155,15 +157,15 @@ def test_max_events_from_config():
 
 
 def test_allowed_tels():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     reader = EventSource(input_url=dataset)
     assert reader.allowed_tels is None
     reader = EventSource(input_url=dataset, allowed_tels={1, 3})
-    assert len(reader.allowed_tels) == 2
+    assert reader.allowed_tels == {1, 3}
 
 
 def test_allowed_tels_from_config():
-    dataset = get_dataset_path("gamma_test_large.simtel.gz")
+    dataset = get_dataset_path(prod5_path)
     config = Config({"EventSource": {"input_url": dataset, "allowed_tels": {1, 3}}})
     reader = EventSource(config=config, parent=None)
-    assert len(reader.allowed_tels) == 2
+    assert reader.allowed_tels == {1, 3}
