@@ -8,7 +8,11 @@ dataset = get_dataset_path("gamma_test_large.simtel.gz")
 
 def test_eventseeker():
 
-    with SimTelEventSource(input_url=dataset, back_seekable=True) as reader:
+    with SimTelEventSource(
+        input_url=dataset,
+        back_seekable=True,
+        focal_length_choice='nominal',
+    ) as reader:
 
         seeker = EventSeeker(event_source=reader)
 
@@ -33,7 +37,8 @@ def test_eventseeker():
             seeker.get_event_index(dict())
 
     with SimTelEventSource(
-        input_url=dataset, max_events=5, back_seekable=True
+        input_url=dataset, max_events=5, back_seekable=True,
+        focal_length_choice='nominal',
     ) as reader:
         seeker = EventSeeker(event_source=reader)
         with pytest.raises(IndexError):
@@ -42,7 +47,10 @@ def test_eventseeker():
 
 
 def test_eventseeker_edit():
-    with SimTelEventSource(input_url=dataset, back_seekable=True) as reader:
+    with SimTelEventSource(
+        input_url=dataset, back_seekable=True,
+        focal_length_choice='nominal',
+    ) as reader:
         seeker = EventSeeker(event_source=reader)
         event = seeker.get_event_index(1)
         assert event.count == 1
@@ -54,7 +62,10 @@ def test_eventseeker_edit():
 
 def test_eventseeker_simtel():
     # Ensure the EventSeeker can forward seek even if back-seeking is not possible
-    with SimTelEventSource(input_url=dataset, back_seekable=False) as reader:
+    with SimTelEventSource(
+        input_url=dataset, back_seekable=False,
+        focal_length_choice='nominal',
+    ) as reader:
         seeker = EventSeeker(event_source=reader)
         event = seeker.get_event_index(1)
         assert event.count == 1
