@@ -2,8 +2,8 @@ import copy
 from ctapipe.instrument.camera.geometry import UnknownPixelShapeWarning
 
 import numpy as np
-from astropy.utils.data import download_file
 import astropy.units as u
+from astropy.coordinates import Angle
 from itertools import zip_longest
 import pytest
 from astropy.time import Time
@@ -20,18 +20,21 @@ from ctapipe.io import DataLevel
 gamma_test_large_path = get_dataset_path("gamma_test_large.simtel.gz")
 gamma_test_path = get_dataset_path("gamma_test.simtel.gz")
 calib_events_path = get_dataset_path("lst_prod3_calibration_and_mcphotons.simtel.zst")
+prod5b_path = get_dataset_path("gamma_20deg_0deg_run2___cta-prod5-paranal_desert-2147m-Paranal-dark_cone10-100evts.simtel.zst")
 
 
 def test_positional_input():
-    source = SimTelEventSource(gamma_test_large_path)
-    assert source.input_url == Path(gamma_test_large_path)
+    source = SimTelEventSource(prod5b_path)
+    assert source.input_url == Path(prod5b_path)
 
 
 def test_simtel_event_source_on_gamma_test_one_event():
+    assert SimTelEventSource.is_compatible(gamma_test_large_path)
+
     with SimTelEventSource(
-        input_url=gamma_test_large_path, back_seekable=True
+        input_url=gamma_test_large_path, back_seekable=True,
+        focal_length_choice='nominal',
     ) as reader:
-        assert reader.is_compatible(gamma_test_large_path)
         assert not reader.is_stream
 
         for event in reader:
@@ -47,7 +50,7 @@ def test_simtel_event_source_on_gamma_test_one_event():
 
 def test_that_event_is_not_modified_after_loop():
 
-    dataset = gamma_test_large_path
+    dataset = prod5b_path
     with SimTelEventSource(input_url=dataset, max_events=2) as source:
         for event in source:
             last_event = copy.deepcopy(event)
@@ -61,12 +64,11 @@ def test_that_event_is_not_modified_after_loop():
 
 
 def test_additional_meta_data_from_simulation_config():
-    with SimTelEventSource(input_url=gamma_test_large_path) as reader:
-        next(iter(reader))
-
-    # for expectation values
-    from astropy import units as u
-    from astropy.coordinates import Angle
+    with SimTelEventSource(
+        input_url=gamma_test_large_path,
+        focal_length_choice='nominal',
+    ) as reader:
+        pass
 
     # There should be only one observation
     assert len(reader.obs_ids) == 1
@@ -104,7 +106,10 @@ def test_additional_meta_data_from_simulation_config():
 
 
 def test_properties():
-    source = SimTelEventSource(input_url=gamma_test_large_path)
+    source = SimTelEventSource(
+        input_url=gamma_test_large_path,
+        focal_length_choice='nominal',
+    )
 
     assert source.is_simulation
     assert source.datalevels == (DataLevel.R0, DataLevel.R1)
@@ -112,11 +117,14 @@ def test_properties():
     assert source.simulation_config[7514].corsika_version == 6990
 
 
-def test_gamma_file():
+def test_gamma_file_prod2():
     dataset = gamma_test_path
 
     with pytest.warns(UnknownPixelShapeWarning):
-        with SimTelEventSource(input_url=dataset) as reader:
+        with SimTelEventSource(
+            input_url=dataset,
+            focal_length_choice='nominal',
+        ) as reader:
             assert reader.is_compatible(dataset)
             assert reader.is_stream  # using gzip subprocess makes it a stream
 
@@ -134,7 +142,9 @@ def test_gamma_file():
 def test_max_events():
     max_events = 5
     with SimTelEventSource(
-        input_url=gamma_test_large_path, max_events=max_events
+        input_url=gamma_test_large_path,
+        max_events=max_events,
+        focal_length_choice='nominal',
     ) as reader:
         count = 0
         for _ in reader:
@@ -143,7 +153,11 @@ def test_max_events():
 
 
 def test_pointing():
-    with SimTelEventSource(input_url=gamma_test_large_path, max_events=3) as reader:
+    with SimTelEventSource(
+        input_url=gamma_test_large_path,
+        max_events=3,
+        focal_length_choice='nominal',
+    ) as reader:
         for e in reader:
             assert np.isclose(e.pointing.array_altitude.to_value(u.deg), 70)
             assert np.isclose(e.pointing.array_azimuth.to_value(u.deg), 0)
@@ -160,7 +174,8 @@ def test_allowed_telescopes():
     # test that the allowed_tels mask works:
     allowed_tels = {3, 4}
     with SimTelEventSource(
-        input_url=gamma_test_large_path, allowed_tels=allowed_tels, max_events=5
+        input_url=gamma_test_large_path, allowed_tels=allowed_tels, max_events=5,
+        focal_length_choice='nominal',
     ) as reader:
         assert not allowed_tels.symmetric_difference(reader.subarray.tel_ids)
         for event in reader:
@@ -188,7 +203,8 @@ def test_calibration_events():
         EventType.SUBARRAY,
     ]
     with SimTelEventSource(
-        input_url=calib_events_path, skip_calibration_events=False
+        input_url=calib_events_path, skip_calibration_events=False,
+        focal_length_choice='nominal',
     ) as reader:
 
         for event, expected_type in zip_longest(reader, expected_types):
@@ -197,7 +213,10 @@ def test_calibration_events():
 
 def test_trigger_times():
 
-    source = SimTelEventSource(input_url=calib_events_path)
+    source = SimTelEventSource(
+        input_url=calib_events_path,
+        focal_length_choice='nominal',
+    )
     t0 = Time("2020-05-06T15:30:00")
     t1 = Time("2020-05-06T15:40:00")
 
@@ -209,7 +228,10 @@ def test_trigger_times():
 
 
 def test_true_image():
-    with SimTelEventSource(input_url=calib_events_path) as reader:
+    with SimTelEventSource(
+        input_url=calib_events_path,
+        focal_length_choice='nominal',
+    ) as reader:
 
         for event in reader:
             for tel in event.simulation.tel.values():
@@ -218,7 +240,10 @@ def test_true_image():
 
 def test_instrument():
     """Test if same telescope types share a single instance of CameraGeometry"""
-    source = SimTelEventSource(input_url=gamma_test_large_path)
+    source = SimTelEventSource(
+        input_url=gamma_test_large_path,
+        focal_length_choice='nominal',
+    )
     subarray = source.subarray
     assert subarray.tel[1].optics.num_mirrors == 1
 
@@ -278,39 +303,36 @@ def test_apply_simtel_r1_calibration_2_channel():
     assert r1_waveforms[1, 0] == (r0_waveforms[0, 1, 0] - ped[0, 1]) * dc_to_pe[0, 1]
 
 
-def test_effective_focal_length():
-    test_file_url = (
-        "https://github.com/cta-observatory/pyeventio/raw/master/tests"
-        "/resources/prod4_pixelsettings_v3.gz"
-    )
-    test_file = download_file(test_file_url)
+def test_focal_length_choice():
+    # this file does not contain the effective focal length
+    with pytest.raises(RuntimeError):
+        SimTelEventSource(gamma_test_large_path)
 
-    focal_length_nominal = 0
-    focal_length_effective = 0
+    with pytest.raises(RuntimeError):
+        SimTelEventSource(gamma_test_large_path, focal_length_choice='effective')
 
-    with SimTelEventSource(
-        input_url=test_file, focal_length_choice="nominal"
-    ) as source:
-        subarray = source.subarray
-        focal_length_nominal = subarray.tel[1].optics.equivalent_focal_length
+    s = SimTelEventSource(gamma_test_large_path, focal_length_choice='nominal')
+    assert s.subarray.tel[1].optics.equivalent_focal_length == 28 * u.m
 
-    with SimTelEventSource(
-        input_url=test_file, focal_length_choice="effective"
-    ) as source:
-        subarray = source.subarray
-        focal_length_effective = subarray.tel[1].optics.equivalent_focal_length
+    # this file does
+    s = SimTelEventSource(prod5b_path, focal_length_choice='effective')
+    assert u.isclose(s.subarray.tel[1].optics.equivalent_focal_length, 29.3 * u.m, atol=0.05 * u.m)
+    # check guessing of the name is not affected by focal length choice
+    assert str(s.subarray.tel[1]) == 'LST_LST_LSTCam'
+
+    s = SimTelEventSource(prod5b_path, focal_length_choice='nominal')
+    assert u.isclose(s.subarray.tel[1].optics.equivalent_focal_length, 28.0 * u.m, atol=0.05 * u.m)
+    # check guessing of the name is not affected by focal length choice
+    assert str(s.subarray.tel[1]) == 'LST_LST_LSTCam'
 
-    assert focal_length_nominal > 0
-    assert focal_length_effective > 0
-    assert focal_length_nominal != focal_length_effective
 
 
 def test_only_config():
     config = Config()
-    config.SimTelEventSource.input_url = gamma_test_large_path
+    config.SimTelEventSource.input_url = prod5b_path
 
     s = SimTelEventSource(config=config)
-    assert s.input_url == Path(gamma_test_large_path).absolute()
+    assert s.input_url == Path(prod5b_path).absolute()
 
 
 def test_calibscale_and_calibshift(prod5_gamma_simtel_path):
@@ -355,11 +377,17 @@ def test_calibscale_and_calibshift(prod5_gamma_simtel_path):
 
 def test_true_image_sum():
     # this file does not contain true pe info
-    with SimTelEventSource(gamma_test_large_path) as s:
+    with SimTelEventSource(
+        gamma_test_large_path,
+        focal_length_choice='nominal',
+    ) as s:
         e = next(iter(s))
         assert np.all(np.isnan(sim.true_image_sum) for sim in e.simulation.tel.values())
 
-    with SimTelEventSource(calib_events_path) as s:
+    with SimTelEventSource(
+        calib_events_path,
+        focal_length_choice='nominal',
+    ) as s:
         e = next(iter(s))
 
         true_image_sums = {}
@@ -371,8 +399,10 @@ def test_true_image_sum():
 
     # check it also works with allowed_tels, since the values
     # are stored in a flat array in simtel
-    with SimTelEventSource(calib_events_path, allowed_tels={2, 3}) as s:
+    with SimTelEventSource(
+        calib_events_path, allowed_tels={2, 3},
+        focal_length_choice='nominal',
+    ) as s:
         e = next(iter(s))
-
         assert e.simulation.tel[2].true_image_sum == true_image_sums[2]
         assert e.simulation.tel[3].true_image_sum == true_image_sums[3]
